﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Workflow.ComponentModel;
using System.Linq;
using System.Text;
using info.ipaw.pc3.PSLoadWorkflow;
using ScientificWorkflow;


namespace Microsoft.Research.eResearch.PC3.Activity {
  [WorkflowCategory("PC3/PostLoad")]
  [Name("IsMatchTableColumnRanges")]
  [Description("Checks if the value ranges of the columns loaded into the table fall within the valid ranges for that column and CSV file type")]
  public class IsMatchTableColumnRangesActivity : System.Workflow.ComponentModel.Activity {

    #region Input Dependency Properties

    public static DependencyProperty FileEntryProperty =
        DependencyProperty.Register("FileEntry", typeof (LoadAppLogic.CSVFileEntry),
                                    typeof (IsMatchTableColumnRangesActivity));

    public static DependencyProperty DBEntryProperty =
        DependencyProperty.Register("DBEntry", typeof(LoadAppLogic.DatabaseEntry),
                                    typeof(IsMatchTableColumnRangesActivity));


    [RequiredInputParam]
    [Name("CSVFileEntry")]
    [Description("File Entry with type of CSV file contained in the table")]
    public LoadAppLogic.CSVFileEntry FileEntry {
      get { return ((LoadAppLogic.CSVFileEntry)(base.GetValue(IsMatchTableColumnRangesActivity.FileEntryProperty))); }
      set { base.SetValue(IsMatchTableColumnRangesActivity.FileEntryProperty, value); }
    }

    [RequiredInputParam]
    [Name("DBEntry")]
    [Description("Database containing the table columns to check")]
    public LoadAppLogic.DatabaseEntry DBEntry {
      get { return ((LoadAppLogic.DatabaseEntry)(base.GetValue(IsMatchTableColumnRangesActivity.DBEntryProperty))); }
      set { base.SetValue(IsMatchTableColumnRangesActivity.DBEntryProperty, value); }
    }

    #endregion

    #region Output dependency Properties

    public static DependencyProperty IsMatchProperty =
        DependencyProperty.Register("IsMatch", typeof(bool), typeof(IsMatchTableColumnRangesActivity));

    [OutputParam]
    [Name("IsMatch")]
    [Description("True if the rows found equal expected row count. False otherwise.")]
    public bool IsMatch {
      get { return ((bool)(base.GetValue(IsMatchTableColumnRangesActivity.IsMatchProperty))); }
      set { base.SetValue(IsMatchTableColumnRangesActivity.IsMatchProperty, value); }
    }
    #endregion

    #region Execution
    protected override ActivityExecutionStatus Execute( ActivityExecutionContext executionContext ) {

      IsMatch = LoadAppLogic.IsMatchTableColumnRanges(DBEntry, FileEntry);

      return base.Execute(executionContext);
    }
    #endregion
  }
}