﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Workflow.ComponentModel;
using System.Linq;
using System.Text;
using info.ipaw.pc3.PSLoadWorkflow;
using ScientificWorkflow;


namespace Microsoft.Research.eResearch.PC3.Activity {
  [WorkflowCategory("PC3/PostLoad")]
  [Name("IsMatchTableRowCount")]
  [Description("Checks if the numbers of rows loaded into the table is same as the number of expected rows in the CSV file")]
  public class IsMatchTableRowCountActivity : System.Workflow.ComponentModel.Activity {

    #region Input Dependency Properties

    public static DependencyProperty FileEntryProperty =
        DependencyProperty.Register("FileEntry", typeof (LoadAppLogic.CSVFileEntry),
                                    typeof (IsMatchTableRowCountActivity));

    public static DependencyProperty DBEntryProperty =
        DependencyProperty.Register("DBEntry", typeof(LoadAppLogic.DatabaseEntry),
                                    typeof(IsMatchTableRowCountActivity));


    [RequiredInputParam]
    [Name("CSVFileEntry")]
    [Description("File Entry with expected number of rows")]
    public LoadAppLogic.CSVFileEntry FileEntry {
      get { return ((LoadAppLogic.CSVFileEntry)(base.GetValue(IsMatchTableRowCountActivity.FileEntryProperty))); }
      set { base.SetValue(IsMatchTableRowCountActivity.FileEntryProperty, value); }
    }

    [RequiredInputParam]
    [Name("DBEntry")]
    [Description("Database containing the table to check")]
    public LoadAppLogic.DatabaseEntry DBEntry {
      get { return ((LoadAppLogic.DatabaseEntry)(base.GetValue(IsMatchTableRowCountActivity.DBEntryProperty))); }
      set { base.SetValue(IsMatchTableRowCountActivity.DBEntryProperty, value); }
    }

    #endregion

    #region Output dependency Properties

    public static DependencyProperty IsMatchProperty =
        DependencyProperty.Register("IsMatch", typeof(bool), typeof(IsMatchTableRowCountActivity));

    [OutputParam]
    [Name("IsMatch")]
    [Description("True if the rows found equal expected row count. False otherwise.")]
    public bool IsMatch {
      get { return ((bool)(base.GetValue(IsMatchTableRowCountActivity.IsMatchProperty))); }
      set { base.SetValue(IsMatchTableRowCountActivity.IsMatchProperty, value); }
    }
    #endregion

    #region Execution
    protected override ActivityExecutionStatus Execute( ActivityExecutionContext executionContext ) {

      IsMatch = LoadAppLogic.IsMatchTableRowCount(DBEntry, FileEntry);

      return base.Execute(executionContext);
    }
    #endregion
  }
}