﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Workflow.ComponentModel;
using System.Linq;
using System.Text;
using info.ipaw.pc3.PSLoadWorkflow;
using ScientificWorkflow;


namespace Microsoft.Research.eResearch.PC3.Activity {
  [WorkflowCategory("PC3/Load")]
  [Name("LoadCSVFileIntoTable")]
  [Description("Loads a CSV File into an existing table using Sql BULK INSERT command")]
  public class LoadCSVFileIntoTableActivity : System.Workflow.ComponentModel.Activity {

    #region Input Dependency Properties

    public static DependencyProperty DBEntryProperty = DependencyProperty.Register(
    "DBEntry", typeof(LoadAppLogic.DatabaseEntry), typeof(LoadCSVFileIntoTableActivity));
    public static DependencyProperty FileEntryProperty = DependencyProperty.Register(
    "FileEntry", typeof(LoadAppLogic.CSVFileEntry), typeof(LoadCSVFileIntoTableActivity));

    [RequiredInputParam]
    [Name("DBEntry")]
    [Description("Database into which to load the CSV file")]
    public LoadAppLogic.DatabaseEntry DBEntry {
      get { return ((LoadAppLogic.DatabaseEntry)(base.GetValue(LoadCSVFileIntoTableActivity.DBEntryProperty))); }
      set { base.SetValue(LoadCSVFileIntoTableActivity.DBEntryProperty, value); }
    }

    [RequiredInputParam]
    [Name("CSVFileEntry")]
    [Description("File to be bulk loaded into database table")]
    public LoadAppLogic.CSVFileEntry FileEntry {
      get { return ((LoadAppLogic.CSVFileEntry)(base.GetValue(LoadCSVFileIntoTableActivity.FileEntryProperty))); }
      set { base.SetValue(LoadCSVFileIntoTableActivity.FileEntryProperty, value); }
    }

    #endregion

    #region Output dependency Properties

    public static DependencyProperty IsLoadedProperty = DependencyProperty.Register(
    "IsLoaded", typeof(bool), typeof(LoadCSVFileIntoTableActivity));

    [OutputParam]
    [Name("IsLoaded")]
    [Description("True if the bulk load ran without exceptions. False otherwise.")]
    public bool IsLoaded {
      get { return ((bool)(base.GetValue(LoadCSVFileIntoTableActivity.IsLoadedProperty))); }
      set { base.SetValue(LoadCSVFileIntoTableActivity.IsLoadedProperty, value); }
    }


    #endregion

    #region Execution
    protected override ActivityExecutionStatus Execute( ActivityExecutionContext executionContext ) {

      IsLoaded = LoadAppLogic.LoadCSVFileIntoTable(DBEntry, FileEntry);

      return base.Execute(executionContext);
    }
    #endregion
  }
}