﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Workflow.ComponentModel;
using System.Linq;
using System.Text;
using info.ipaw.pc3.PSLoadWorkflow;
using ScientificWorkflow;


namespace Microsoft.Research.eResearch.PC3.Activity {
  [WorkflowCategory("PC3/Load")]
  [Name("UpdateComputedColumns")]
  [Description("Updates the derived columns in the database table matching the CSV file type.")]
  public class UpdateComputedColumnsActivity : System.Workflow.ComponentModel.Activity {

    #region Input Dependency Properties

    public static DependencyProperty DBEntryProperty = DependencyProperty.Register(
        "DBEntry", typeof (LoadAppLogic.DatabaseEntry), typeof (UpdateComputedColumnsActivity));

    public static DependencyProperty FileEntryProperty = DependencyProperty.Register(
        "FileEntry", typeof (LoadAppLogic.CSVFileEntry), typeof (UpdateComputedColumnsActivity));

    [RequiredInputParam]
    [Name("DBEntry")]
    [Description("Database containin the tables whose computed columsn to update")]
    public LoadAppLogic.DatabaseEntry DBEntry {
      get { return ((LoadAppLogic.DatabaseEntry)(base.GetValue(UpdateComputedColumnsActivity.DBEntryProperty))); }
      set { base.SetValue(UpdateComputedColumnsActivity.DBEntryProperty, value); }
    }

    [RequiredInputParam]
    [Name("CSVFileEntry")]
    [Description("File Entry with type of CSV file contained in the table")]
    public LoadAppLogic.CSVFileEntry FileEntry {
      get { return ((LoadAppLogic.CSVFileEntry)(base.GetValue(UpdateComputedColumnsActivity.FileEntryProperty))); }
      set { base.SetValue(UpdateComputedColumnsActivity.FileEntryProperty, value); }
    }

    #endregion

    #region Output dependency Properties

    public static DependencyProperty IsUpdatedProperty = DependencyProperty.Register(
        "IsUpdated", typeof (bool), typeof (UpdateComputedColumnsActivity));

    [OutputParam]
    [Name("IsUpdated")]
    [Description("True if the columns were updated without exceptions. False otherwise.")]
    public bool IsUpdated {
      get { return ((bool)(base.GetValue(UpdateComputedColumnsActivity.IsUpdatedProperty))); }
      set { base.SetValue(UpdateComputedColumnsActivity.IsUpdatedProperty, value); }
    }


    #endregion

    #region Execution
    protected override ActivityExecutionStatus Execute( ActivityExecutionContext executionContext ) {

      IsUpdated = LoadAppLogic.UpdateComputedColumns(DBEntry, FileEntry);

      return base.Execute(executionContext);
    }
    #endregion
  }
}